@@ -91,7 +91,7 @@ class CGContentUtils extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.3';
+    return '1.3.2';
   }
 
 
@@ -100,7 +100,7 @@ class CGContentUtils extends CGExtensions
    ---------------------------------------------------------*/
   function GetHelp()
   {
-    return $this->Lang('help');
+    return file_get_contents(dirname(__FILE__).'/help.inc');
   }
 
 
@@ -127,7 +127,7 @@ class CGContentUtils extends CGExtensions
    ---------------------------------------------------------*/
   function GetChangeLog()
   {
-    return file_get_contents(dirname(__FILE__).'/changeloc.inc');
+    return file_get_contents(dirname(__FILE__).'/changelog.inc');
   }
   
   /*---------------------------------------------------------
@@ -193,7 +193,7 @@ class CGContentUtils extends CGExtensions
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.22.1',
+    return array('CGExtensions'=>'1.29',
 		 'JQueryTools'=>'1.0.3');
   }
 
@@ -222,7 +222,7 @@ EOT;
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.9.4.3";
+    return "1.10.2";
   }
 	
 	
@@ -404,9 +404,6 @@ EOT;
     $root = $this->_dom->createElement('cms_content');
     $root->setAttribute('name',$content_obj->Name());
 
-//     $sub = $this->_dom->createElement('name',$content_obj->Name());
-//     $root->appendChild($sub);
-
     $sub = $this->_dom->createElement('type',$content_obj->Type());
     $root->appendChild($sub);
 
@@ -440,29 +437,18 @@ EOT;
     $sub = $this->_dom->createElement('showinmenu',$content_obj->ShowInMenu());
     $root->appendChild($sub);
 
+    $content_obj->HasProperty('___'); // fools properties to be loaded.
     $props = $content_obj->Properties();
-    foreach( $props->mPropertyNames as $name )
-      {
-	if( !isset($props->mPropertyValues[$name]) ) continue;
-	if( !$props->mPropertyValues[$name] ) continue;
-
+    if( is_array($props) && count($props) ) {
+      foreach( $props as $name => $val ) {
 	$sub = $this->_dom->createElement('property');
 	$sub->setAttribute('name',$name);
-	$sub->setAttribute('type',$props->mPropertyTypes[$name]);
-	$cdata = $this->_dom->createCDATAsection($props->mPropertyValues[$name]);
+	$sub->setAttribute('type','string');
+	$cdata = $this->_dom->createCDATAsection($val);
 	$sub->appendChild($cdata);
-
-// 	$sub2 = $this->_dom->createElement('propname',$name);
-// 	$sub->appendChild($sub2);
-
-// 	$sub2 = $this->_dom->createElement('proptype',$props->mPropertyTypes[$name]);
-// 	$sub->appendChild($sub2);
-
-// 	$sub2 = $this->_dom->createElement('propvalue');
-// 	$sub2->appendChild($cdata);
-
 	$root->appendChild($sub);
       }
+    }
 
     return $root;
   }
@@ -516,7 +502,6 @@ EOT;
 	$content_obj = $this->_extractDomContentObj($node);
 	if( $content_obj )
 	  {
-	    echo "DEBGUG: FOUND ".$content_obj->Name().' with parent '.$parent_id.'<br/>';
 	    //see if there are more.
 	    scan_content($node->firstChild,$parent_id++);
 	  }
@@ -544,7 +529,6 @@ EOT;
 		$content_obj->SetOwner(get_userid());
 		$content_obj->Save();
 		$new_parent_id = $content_obj->Id();
-		echo "DEBGUG: Added ".$content_obj->Name().' with id '.$parent_id.'<br/>';
 		//see if there are more.
 		$this->_importContent($node->firstChild,$new_parent_id);
 	      }
