@@ -16,27 +16,6 @@ $lang['blocktype_file_selector'] = 'Dateiauswahl';
 $lang['blocktype_pageselector'] = 'Seitenauswahl';
 $lang['blocktype_radiobuttons'] = 'Optionsfelder';
 $lang['cancel'] = 'Abbrechen';
-$lang['changelog'] = '<ul>
-  <li>v1.0 - June 2009
-    <ul>
-      <li>Initial Relase</li>
-    </ul>
-  </li>
-  <li>v1.0.2 - July 2010
-    <ul>
-      <li>Ability to perserve hierarchy when copying parents and children (Ted)</li>
-      <li>Added check for prop copying to keep E_NOTICE happy (Ted)></li>
-      <li>Minor change to sample tag info.</li>
-      <li>Adds the page selector field type.</li>
-    </ul>
-  </li>
-  <li>v1.2 - December 2010
-    <ul> 
-      <li>Adds the export and import code functionality.</li>
-    </ul>
-  </li>
-</ul>
-TODO';
 $lang['content'] = 'Inhalt';
 $lang['contents_of_file'] = 'Gescannte Inhalte und Dateien';
 $lang['copy'] = 'Kopieren';
@@ -129,7 +108,7 @@ $lang['info_final_import_code'] = 'Die f&uuml;r den Import ausgew&auml;hlten Ein
 <strong>Hinweis:</strong> Einige Module unterst&uuml;tzen nicht mehrere Templates f&uuml;r jeden Template-Typ. Es kann daher erforderlich sein, dass einige Templates &uuml;berschrieben werden m&uuml;ssen, damit der Import funktioniert.<br/>
 <strong>Hinweis:</strong> Dieses Modul nimmt keinerlei Ver&auml;nderungen an den importierten Templates vor, um Referenzen auf Seiten oder Modulaufrufe zu pr&uuml;fen. Sie m&uuml;ssen daher anschlie&szlig;end jedes Template individuell an die Bed&uuml;rftnisse der Webseite anpassen.';
 $lang['info_import_code'] = 'Den Import der ausgew&auml;hlten Globalen Inhaltsbl&ouml;cke, Benutzerdefinierten Tags und Modul-Templates aus einer XML-Datei erlauben.<br/><strong>Hinweis:</strong> Dies ist eine Funktion f&uuml;r fortgeschrittene Anwender. Damit k&ouml;nnen die Templates einer existierenden Seite &uuml;berschrieben werden. Verwenden Sie diese Funktion daher mit Vorsicht!';
-$lang['info_scanned_file'] = 'Sie finden im folgenden die gescannten Inhalte der angegebenen XML-Datei. Sie k&ouml;nnen sich eine Vorschau der Eintr&auml;ge ansehen und einige f&uuml;r den Import ausw&auml;hlen. Au&szlig;erdem k&ouml;nnen Sie optional einen neuen Namen f&uuml;r die importierten Templates festlegen.';
+$lang['info_scanned_file'] = 'Sie finden im folgenden die eingelesenen Inhalte der angegebenen XML-Datei. Sie k&ouml;nnen sich eine Vorschau der Eintr&auml;ge ansehen und einige f&uuml;r den Import ausw&auml;hlen. Au&szlig;erdem k&ouml;nnen Sie optional einen neuen Namen f&uuml;r die importierten Templates festlegen.';
 $lang['import'] = 'Importieren';
 $lang['import_code'] = 'Code importieren';
 $lang['import_content'] = 'Inhalt importieren';
@@ -175,8 +154,8 @@ $lang['type'] = 'Typ';
 $lang['usage'] = 'Verwendung';
 $lang['userdefined_tag'] = 'Benutzerdefinierter Tag (UDT)';
 $lang['xml_file'] = 'XML-Datei';
-$lang['utma'] = '156861353.543163381.1302603430.1302688208.1302774458.3';
-$lang['utmz'] = '156861353.1302603430.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1865716571.1334693985.1334693985.1334779289.2';
+$lang['utmz'] = '156861353.1334693985.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
